[−][src]Enum cursive_multiplex::Path
Path is a recursive enum made to be able to identify a pane by it's actual location in the multiplexer. An upper Pane on the left side for example would have the path Path::LeftOrUp(Box::new(Some(Path::LeftOrUp(Box::new(None))))).
Variants
LeftOrUp(Box<Option<Path>>)RightOrDown(Box<Option<Path>>)Trait Implementations